XivUniversalis Documentation
============================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   universalis
   models

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`